# SCV

## Original code

[https://github.com/zacjiang/SCV](https://github.com/zacjiang/SCV)

## Additional requirements

In order to use SCV you need to install two additional requirements:

- torch_scatter: Check [https://github.com/rusty1s/pytorch_scatter](https://github.com/rusty1s/pytorch_scatter) for installation instructions.
- faiss: install with `pip install faiss-gpu`

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

Not specified.

## Citation

```
@inproceedings{jiang2021learning,
  title={Learning Optical Flow from a Few Matches},
  author={Jiang, Shihao and Lu, Yao and Li, Hongdong and Hartley, Richard},
  booktitle={CVPR},
  pages={16592--16600},
  year={2021}
}
```